"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var BaseError = (function (_super) {
    tslib_1.__extends(BaseError, _super);
    function BaseError() {
        var _this = _super.call(this) || this;
        _this.code = 'UNKNOWN';
        _this.explanation = 'No explanation was given';
        _this.description = "There was an unknown error\n\n    It might be a bug in our code and we still don't know what it is.\n    It might be as well a network or IO problem.\n    But there's a chance it might be your fault, sending some incorrectly parameter or in the wrong format.\n\n    Please check the information below for useful data to fire a bug or correct your code.\n\n    Thanks!";
        return _this;
    }
    BaseError.prototype.getOriginal = function () {
        var original = this.original;
        if (!original) {
            return 'No original error information. This might be the root cause!';
        }
        this.stack = '';
        var stack = original.stack.split('\n');
        var lines = stack.length;
        delete this.original;
        return stack.slice(0, 5).join('\n') + "\n      ... " + lines + " additional lines";
    };
    BaseError.prototype.getMessage = function (original) {
        return "\n    " + this.code + "\n    " + this.description + "\n    " + this.explanation + "\n\n    Original stack:\n    " + original + "\n    ";
    };
    return BaseError;
}(Error));
exports.BaseError = BaseError;
//# sourceMappingURL=base.error.js.map